// luma.gl
// SPDX-License-Identifier: MIT
// Copyright (c) vis.gl contributors
import { glsl } from "../../../lib/glsl-utils/highlight.js";
const vs = `\
attribute float transform_elementID;
vec2 transform_getPixelSizeHalf(vec2 size) {
return vec2(1.) / (2. * size);
}
vec2 transform_getPixelIndices(vec2 texSize, vec2 pixelSizeHalf) {
float yIndex = floor((transform_elementID / texSize[0]) + pixelSizeHalf[1]);
float xIndex = transform_elementID - (yIndex * texSize[0]);
return vec2(xIndex, yIndex);
}
vec2 transform_getTexCoord(vec2 size) {
vec2 pixelSizeHalf = transform_getPixelSizeHalf(size);
vec2 indices = transform_getPixelIndices(size, pixelSizeHalf);
vec2 coord = indices / size + pixelSizeHalf;
return coord;
}
vec2 transform_getPos(vec2 size) {
vec2 texCoord = transform_getTexCoord(size);
vec2 pos = (texCoord * (2.0, 2.0)) - (1., 1.);
return pos;
}
vec4 transform_getInput(sampler2D texSampler, vec2 size) {
vec2 texCoord = transform_getTexCoord(size);
vec4 textureColor = texture2D(texSampler, texCoord);
return textureColor;
}
`;
/** Private shader module used by `Transform` */
export const transform = {
    name: 'transform',
    vs
};
